@@ -1,6 +1,5 @@
 perldocSearch.indexData.modules = new Hash ({
   "attributes": "get/set subroutine or variable attributes",
-  "attrs": "set/get attributes of a subroutine (deprecated)",
   "autodie": "Replace functions with ones that succeed or die with lexical scope",
   "autouse": "postpone load of modules until a function is used",
   "base": "Establish an ISA relationship with base classes at compile time",
@@ -9,11 +8,11 @@ perldocSearch.indexData.modules = new Hash ({
   "bigrat": "Transparent BigNumber/BigRational support for Perl",
   "blib": "Use MakeMaker's uninstalled version of a package",
   "bytes": "Perl pragma to force byte semantics rather than character semantics",
-  "charnames": "define character names for \\N{named} string literal escapes",
+  "charnames": "access to Unicode character names and named character sequences; also define character names",
   "constant": "Perl pragma to declare constants",
   "diagnostics": "produce verbose warning diagnostics",
   "encoding": "allows you to write your script in non-ascii or non-utf8",
-  "feature": "Perl pragma to enable new syntactic features",
+  "feature": "Perl pragma to enable new features",
   "fields": "compile-time class fields",
   "filetest": "Perl pragma to control the filetest permission operators",
   "if": "use a Perl module if a condition holds",
@@ -46,10 +45,10 @@ perldocSearch.indexData.modules = new Hash ({
   "ExtUtils::Embed": "Utilities for embedding Perl in C/C++ applications",
   "Text::Tabs": "expand and unexpand tabs per the unix expand(1) and unexpand(1)",
   "ExtUtils::MakeMaker": "Create a module Makefile",
-  "Log::Message::Simple": "Log::Message::Simple",
+  "Log::Message::Simple": "Simplified interface to Log::Message",
   "PerlIO::encoding": "encoding layer",
   "Text::ParseWords": "parse text into an array of tokens or array of arrays",
-  "IPC::Open2": "open a process for both reading and writing",
+  "IPC::Open2": "open a process for both reading and writing using open2()",
   "File::stat": "by-name interface to Perl's built-in stat() functions",
   "Pod::Simple::PullParserEndToken": "end-tokens from Pod::Simple::PullParser",
   "Shell": "run shell commands transparently within perl",
@@ -60,7 +59,7 @@ perldocSearch.indexData.modules = new Hash ({
   "File::Spec::Functions": "portably perform operations on file names",
   "Socket": "load the C socket.h defines and structure manipulators ",
   "Module::Pluggable": "automatically give your module the ability to have plugins",
-  "Parse::CPAN::Meta": "Parse META.yml and other similar CPAN metadata files",
+  "Parse::CPAN::Meta": "Parse META.yml and META.json CPAN metadata files",
   "Locale::Maketext::Simple": "Simple interface to Locale::Maketext::Lexicon",
   "Tie::File": "Access the lines of a disk file via a Perl array",
   "Encode::GSM0338": "ESTI GSM 03.38 Encoding",
@@ -73,17 +72,17 @@ perldocSearch.indexData.modules = new Hash ({
   "Pod::Simple::HTMLBatch": "convert several Pod files to several HTML files",
   "CGI::Util": "Internal utilities used by CGI module",
   "IO::Pipe": "supply object methods for pipes",
-  "Module::Build::YAML": "Provides just enough YAML support so that Module::Build works even if YAML.pm is not installed",
+  "Module::Build::YAML": "DEPRECATED",
   "ExtUtils::Command": "utilities to replace common UNIX commands in Makefiles etc.",
   "List::Util": "A selection of general-utility list subroutines",
   "Pod::Simple::Search": "find POD documents in directory trees",
   "IO::Uncompress::AnyInflate": "Uncompress zlib-based (zip, gzip) file/buffer",
-  "TAP::Formatter::Base": "Harness output delegate for default console output",
+  "TAP::Formatter::Base": "Base class for harness output delegates",
   "File::Spec::VMS": "methods for VMS file specs",
   "Opcode": "Disable named opcodes when compiling perl code",
   "Archive::Tar": "module for manipulations of tar archives",
-  "TAP::Parser::Result::Pragma": "TAP pragma token.",
   "PerlIO::via::QuotedPrint": "PerlIO layer for quoted-printable strings",
+  "TAP::Parser::Result::Pragma": "TAP pragma token.",
   "File::CheckTree": "run many filetest checks on a tree",
   "File::Copy": "Copy files or filehandles",
   "Encode::EBCDIC": "EBCDIC Encodings",
@@ -91,6 +90,7 @@ perldocSearch.indexData.modules = new Hash ({
   "Net::Netrc": "OO interface to users netrc file",
   "Compress::Raw::Zlib": "Low-Level Interface to zlib compression library",
   "TAP::Parser::YAMLish::Writer": "Write YAMLish data",
+  "Pod::Perldoc::GetOptsOO": "Customized option parser for Pod::Perldoc",
   "Thread::Queue": "Thread-safe queues",
   "CPANPLUS::Dist::Sample": "Sample code to create your own Dist::* plugin",
   "Encode::Encoder": "Object Oriented Encoder",
@@ -118,14 +118,14 @@ perldocSearch.indexData.modules = new Hash ({
   "ExtUtils::CBuilder": "Compile and link C code for Perl modules",
   "DBM_Filter::compress": "filter for DBM_Filter",
   "IO::Uncompress::Gunzip": "Read RFC 1952 files/buffers",
+  "Encode::KR": "Korean Encodings",
   "ExtUtils::Constant::XS": "generate C code for XS modules' constants.",
   "Exporter": "Implements default import method for modules",
-  "Encode::KR": "Korean Encodings",
   "AutoLoader": "load subroutines only on demand",
   "Module::Build::Platform::aix": "Builder class for AIX platform",
   "Pod::Text::Color": "Convert POD data to formatted color ASCII text",
   "Time::tm": "internal object used by Time::gmtime and Time::localtime",
-  "Devel::DProf": "a Perl code profiler",
+  "Devel::DProf": "a DEPRECATED Perl code profiler",
   "Net::NNTP": "NNTP Client class",
   "IO": "load various IO modules",
   "Module::Load": "runtime require of both modules and files",
@@ -139,7 +139,7 @@ perldocSearch.indexData.modules = new Hash ({
   "Module::Build::PPMMaker": "Perl Package Manager file creation",
   "PerlIO::via": "Helper class for PerlIO layers implemented in perl",
   "SelfLoader": "load functions only on demand",
-  "TAP::Parser::Iterator": "Internal base class for TAP::Parser Iterators",
+  "TAP::Parser::Iterator": "Base class for TAP source iterators",
   "TAP::Parser::Result": "Base class for TAP::Parser output objects",
   "Module::CoreList": "what modules shipped with versions of perl",
   "Encode::CJKConstants": "Internally used by Encode::??::ISO_2022_*",
@@ -148,8 +148,8 @@ perldocSearch.indexData.modules = new Hash ({
   "Pod::Simple::PullParserStartToken": "start-tokens from Pod::Simple::PullParser",
   "Pod::Perldoc::ToRtf": "let Perldoc render Pod as RTF",
   "Test::Builder::Module": "Base class for test modules",
-  "IO::Compress::Deflate": "Write RFC 1950 files/buffers",
   "File::Compare": "Compare files or filehandles",
+  "IO::Compress::Deflate": "Write RFC 1950 files/buffers",
   "User::grent": "by-name interface to Perl's built-in getgr*() functions",
   "Pod::Html": "module to convert pod files to HTML",
   "Pod::Perldoc::ToNroff": "let Perldoc convert Pod to nroff",
@@ -159,8 +159,8 @@ perldocSearch.indexData.modules = new Hash ({
   "TAP::Formatter::Console::ParallelSession": "Harness output delegate for parallel console output",
   "Thread": "Manipulate threads in Perl (for old code only)",
   "Unicode::Collate": "Unicode Collation Algorithm",
-  "IO::Compress::Gzip": "Write RFC 1952 files/buffers",
   "CPANPLUS::Module::Fake": "CPANPLUS::Module::Fake",
+  "IO::Compress::Gzip": "Write RFC 1952 files/buffers",
   "Time::HiRes": "High resolution alarm, sleep, gettimeofday, interval timers",
   "Net::protoent": "by-name interface to Perl's built-in getproto*() functions",
   "IPC::Semaphore": "SysV Semaphore IPC object class",
@@ -196,32 +196,33 @@ perldocSearch.indexData.modules = new Hash ({
   "CPANPLUS::Internals::Source": "CPANPLUS::Internals::Source",
   "Pod::Perldoc::ToChecker": "let Perldoc check Pod for errors",
   "Test::Builder": "Backend for building test libraries",
-  "Pod::Plainer": "Perl extension for converting Pod to old style Pod.",
   "DBM_Filter::int32": "filter for DBM_Filter",
   "ExtUtils::MM_NW5": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
   "CGI::Carp": "CGI routines for writing to the HTTPD (or other) error log",
   "Module::Build::Compat": "Compatibility with ExtUtils::MakeMaker",
   "Getopt::Std": "Process single-character switches with switch clustering",
   "Module::Build::Platform::MPEiX": "Builder class for MPEiX platforms",
-  "Object::Accessor": "Object::Accessor",
   "ExtUtils::MM_Win32": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
+  "Object::Accessor": "interface to create per object accessors",
   "File::Fetch": "A generic file fetching mechanism",
   "Term::ReadLine": "Perl interface to various readline packages.If no real package is found, substitutes stubs instead of basic functions.",
   "ExtUtils::Constant::Utils": "helper functions for ExtUtils::Constant",
   "Scalar::Util": "A selection of general-utility scalar subroutines",
-  "Locale::Language": "ISO two letter codes for language identification (ISO 639)",
-  "FindBin": "Locate directory of original perl script",
+  "Locale::Language": "standard codes for language identification",
   "Benchmark": "benchmark running times of Perl code",
+  "FindBin": "Locate directory of original perl script",
   "Net::hostent": "by-name interface to Perl's built-in gethost*() functions",
   "ExtUtils::MY": "ExtUtils::MakeMaker subclass for customization",
   "FileCache": "keep more files open than the system permits",
   "CPANPLUS": "API & CLI access to the CPAN mirrors",
   "Pod::Select": "extract selected sections of POD from input",
+  "Locale::Maketext::GutsLoader": "Deprecated module to load Locale::Maketext utf8 code",
   "TAP::Parser::Result::Plan": "Plan result token.",
   "Encode::JP": "Japanese Encodings",
   "Pod::Checker": "check pod documents for syntax errors",
   "Module::Build::Platform::os2": "Builder class for OS/2 platform",
   "Pod::Text::Termcap": "Convert POD data to ASCII text with format escapes",
+  "Locale::Maketext::Guts": "Deprecated module to load Locale::Maketext utf8 code",
   "ExtUtils::Mkbootstrap": "make a bootstrap file for use by DynaLoader",
   "Pod::Usage": "print a usage message from embedded pod documentation",
   "Pod::Text": "Convert POD data to formatted ASCII text",
@@ -233,13 +234,14 @@ perldocSearch.indexData.modules = new Hash ({
   "IO::File": "supply object methods for filehandles",
   "ExtUtils::ParseXS": "converts Perl XS code into C code",
   "CPANPLUS::Module::Checksums": "CPANPLUS::Module::Checksums",
-  "Module::Build::ModuleInfo": "Gather package and POD information from a perl module file",
+  "Module::Build::ModuleInfo": "DEPRECATED",
   "Encode::MIME::Header": "MIME 'B' and 'Q' header encoding",
   "File::Find": "Traverse a directory tree.",
   "Module::Build::Platform::EBCDIC": "Builder class for EBCDIC platforms",
   "DBM_Filter::encode": "filter for DBM_Filter",
   "Test": "provides a simple framework for writing test scripts",
   "Hash::Util::FieldHash": "Support for Inside-Out Classes",
+  "Module::Build::Version": "DEPRECATED",
   "Exporter::Heavy": "Exporter guts",
   "App::Prove::State::Result": "Individual test suite results.",
   "CPANPLUS::Shell::Default::Plugins::CustomSource": "CPANPLUS::Shell::Default::Plugins::CustomSource ",
@@ -253,11 +255,11 @@ perldocSearch.indexData.modules = new Hash ({
   "ExtUtils::Command::MM": "Commands for the MM's to use in Makefiles",
   "IO::Socket": "Object interface to socket communications",
   "File::Temp": "return name and handle of a temporary file safely",
-  "Locale::Script": "ISO codes for script identification (ISO 15924)",
+  "Locale::Script": "standard codes for script identification",
   "Term::UI::History": "Term::UI::History",
   "TAP::Parser::Result::Test": "Test result token.",
-  "CGI::Push": "Simple Interface to Server Push",
   "Digest::MD5": "Perl interface to the MD5 Algorithm",
+  "CGI::Push": "Simple Interface to Server Push",
   "Text::Balanced": "Extract delimited text sequences from strings.",
   "Net::Domain": "Attempt to evaluate the current host's internet name and domain",
   "TAP::Formatter::Color": "Run Perl test scripts with color",
@@ -267,11 +269,12 @@ perldocSearch.indexData.modules = new Hash ({
   "Unicode::UCD": "Unicode character database",
   "Encode::TW": "Taiwan-based Chinese Encodings",
   "Module::Build::Cookbook": "Examples of Module::Build Usage",
+  "Pod::Perldoc": "Look up Perl documentation in Pod format.",
   "Module::Build::ConfigData": "Configuration for Module::Build",
   "AutoSplit": "split a package for autoloading",
   "Module::Build::Platform::Default": "Stub class for unknown platforms",
   "TAP::Parser::Result::Version": "TAP syntax version token.",
-  "Locale::Country": "ISO codes for country identification (ISO 3166)",
+  "Locale::Country": "standard codes for country identification",
   "Module::Build::Platform::Unix": "Builder class for Unix platforms",
   "File::Path": "Create or remove directory trees",
   "ExtUtils::Mksymlists": "write linker options files for dynamic extension",
@@ -297,7 +300,7 @@ perldocSearch.indexData.modules = new Hash ({
   "App::Prove::State::Result::Test": "Individual test results.",
   "IO::Socket::UNIX": "Object interface for AF_UNIX domain sockets",
   "Test::Builder::Tester::Color": "turn on colour in Test::Builder::Tester",
-  "TAP::Parser::Source": "Stream output from some source",
+  "TAP::Parser::Source": "a TAP source & meta data about it",
   "ExtUtils::MM_UWIN": "U/WIN specific subclass of ExtUtils::MM_Unix",
   "ExtUtils::MM_QNX": "QNX specific subclass of ExtUtils::MM_Unix",
   "Pod::Simple::Checker": "check the Pod syntax of a document",
@@ -305,17 +308,17 @@ perldocSearch.indexData.modules = new Hash ({
   "TAP::Parser::Multiplexer": "Multiplex multiple TAP::Parsers",
   "MIME::QuotedPrint": "Encoding and decoding of quoted-printable strings",
   "Time::Seconds": "a simple API to convert seconds to other date values",
-  "B": "The Perl Compiler",
+  "B": "The Perl Compiler Backend",
   "TAP::Base": "Base class that provides common functionality to TAP::Parserand TAP::Harness",
   "Test::More": "yet another framework for writing test scripts",
   "B::Concise": "Walk Perl syntax tree, printing concise info about ops",
   "PerlIO": "On demand loader for PerlIO layers and root of PerlIO::* name space",
   "ExtUtils::MM_BeOS": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
-  "TAP::Parser::Iterator::Process": "Internal TAP::Parser Iterator",
+  "TAP::Parser::Iterator::Process": "Iterator for process-based TAP sources",
   "IO::Dir": "supply object methods for directory handles",
-  "CGI::Cookie": "Interface to Netscape Cookies",
-  "IO::Uncompress::Inflate": "Read RFC 1950 files/buffers",
+  "CGI::Cookie": "Interface to HTTP Cookies",
   "UNIVERSAL": "base class for ALL classes (blessed references)",
+  "IO::Uncompress::Inflate": "Read RFC 1950 files/buffers",
   "Log::Message::Item": "Message objects for Log::Message",
   "Test::Simple": "Basic utilities for writing tests.",
   "ExtUtils::MM_Cygwin": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
@@ -326,7 +329,7 @@ perldocSearch.indexData.modules = new Hash ({
   "Archive::Extract": "A generic archive extracting mechanism",
   "Module::Build::Platform::MacOS": "Builder class for MacOS platforms",
   "CPAN": "query, download and build perl modules from CPAN sites",
-  "Module::Build::Notes": "Configuration for $module_name",
+  "Module::Build::Notes": "Create persistent distribution configuration modules",
   "Module::Build::Base": "Default methods for Module::Build",
   "Net::netent": "by-name interface to Perl's built-in getnet*() functions",
   "Encode": "character encodings",
@@ -349,8 +352,8 @@ perldocSearch.indexData.modules = new Hash ({
   "Sys::Syslog": "Perl interface to the UNIX syslog(3) calls",
   "Unicode::Normalize": "Unicode Normalization Forms",
   "Filter::Util::Call": "Perl Source Filter Utility Module",
-  "ExtUtils::MM_OS2": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
   "Text::Wrap": "line wrapping to form simple paragraphs",
+  "ExtUtils::MM_OS2": "methods to override UN*X behaviour in ExtUtils::MakeMaker",
   "Text::Abbrev": "create an abbreviation table from a list",
   "Pod::Parser": "base class for creating POD filters and translators",
   "SelectSaver": "save and restore selected file handle",
@@ -363,16 +366,15 @@ perldocSearch.indexData.modules = new Hash ({
   "DBM_Filter::utf8": "filter for DBM_Filter",
   "Time::Local": "efficiently compute time from local and GMT time",
   "Pod::Simple::RTF": "format Pod as RTF",
-  "Log::Message::Handlers": "Message handlers for Log::Message",
   "Pod::ParseLink": "Parse an L&lt;&gt; formatting code in POD text",
+  "Log::Message::Handlers": "Message handlers for Log::Message",
   "Pod::Simple::PullParser": "a pull-parser interface to parsing Pod",
   "Tie::Handle": "base class definitions for tied handles",
-  "Text::Soundex": "Implementation of the soundex algorithm.",
-  "CPANPLUS::Config": "CPANPLUS::Config",
-  "Memoize::ExpireFile": "test for Memoize expiration semantics",
   "Module::Build::Platform::RiscOS": "Builder class for RiscOS platforms",
+  "Memoize::ExpireFile": "test for Memoize expiration semantics",
+  "CPANPLUS::Config": "CPANPLUS::Config",
+  "Text::Soundex": "Implementation of the soundex algorithm.",
   "IO::Select": "OO interface to the select system call",
-  "TAP::Parser::Source::Perl": "Stream Perl output",
   "CPANPLUS::Internals::Utils": "CPANPLUS::Internals::Utils",
   "Locale::Maketext": "framework for localization",
   "I18N::Collate": "compare 8-bit scalar data according to the current locale",
@@ -380,21 +382,22 @@ perldocSearch.indexData.modules = new Hash ({
   "TAP::Parser::Scheduler::Job": "A single testing job.",
   "Locale::Constants": "constants for Locale codes",
   "ExtUtils::MakeMaker::Tutorial": "Writing a module with MakeMaker",
-  "ExtUtils::Installed": "Inventory management of installed modules",
   "IO::Uncompress::Base": "Base Class for IO::Uncompress modules ",
+  "ExtUtils::Installed": "Inventory management of installed modules",
   "Encode::CN::HZ": "internally used by Encode::CN",
   "Pod::Perldoc::ToXml": "let Perldoc render Pod as XML",
-  "TAP::Parser::IteratorFactory": "Internal TAP::Parser Iterator",
+  "TAP::Parser::IteratorFactory": "Figures out which SourceHandler objects to use for a given Source",
   "TAP::Harness": "Run test scripts with statistics",
   "Net::Config": "Local configuration data for libnet",
   "ExtUtils::Miniperl": "write the C code for perlmain.c",
   "Archive::Tar::File": "a subclass for in-memory extracted file from Archive::Tar",
-  "TAP::Parser::Iterator::Stream": "Internal TAP::Parser Iterator",
+  "TAP::Parser::Iterator::Stream": "Iterator for filehandle-based TAP sources",
   "Pod::Simple::LinkSection": "represent \"section\" attributes of L codes",
   "IO::Compress::Zip": "Write zip files/buffers",
   "Encode::Alias": "alias definitions to encodings",
   "Memoize::AnyDBM_File": "glue to provide EXISTS for AnyDBM_File for Storable use",
   "Pod::Text::Overstrike": "=for stopwordsoverstrike",
+  "Pod::Perldoc::BaseTo": "Base for Pod::Perldoc formatters",
   "Pod::Escapes": "for resolving Pod E&lt;...&gt; sequences",
   "Storable": "persistence for Perl data structures",
   "TAP::Parser::Scheduler": "Schedule tests during parallel testing",
@@ -407,8 +410,8 @@ perldocSearch.indexData.modules = new Hash ({
   "Pod::Find": "find POD documents in directory trees",
   "English": "use nice English (or awk) names for ugly punctuation variables",
   "Pod::InputObjects": "objects representing POD input paragraphs, commands, etc.",
-  "Tie::Hash": "base class definitions for tied hashes",
   "CPANPLUS::Configure": "CPANPLUS::Configure",
+  "Tie::Hash": "base class definitions for tied hashes",
   "Log::Message::Config": "Configuration options for Log::Message",
   "TAP::Parser::Result::YAML": "YAML result token.",
   "Math::BigInt::Calc": "Pure Perl module to support Math::BigInt",
@@ -419,7 +422,7 @@ perldocSearch.indexData.modules = new Hash ({
   "IO::Handle": "supply object methods for I/O handles",
   "Module::Build::Platform::darwin": "Builder class for Mac OS X platform",
   "TAP::Formatter::Console::Session": "Harness output delegate for default console output",
-  "Carp": "warn of errors (from perspective of caller)",
+  "Carp": "alternative warn and die for modules",
   "Search::Dict": "search for key in dictionary file",
   "CPANPLUS::Dist::MM": "CPANPLUS::Dist::MM",
   "ExtUtils::Liblist": "determine libraries to use and how to use them",
@@ -453,16 +456,14 @@ perldocSearch.indexData.modules = new Hash ({
   "Net::Time": "time and daytime network client interface",
   "Module::Loaded": "mark modules as loaded or unloaded",
   "ExtUtils::MM_AIX": "AIX specific subclass of ExtUtils::MM_Unix",
-  "Class::ISA": "report the search path for a class's ISA tree",
   "Cwd": "get pathname of current working directory",
   "TAP::Parser::ResultFactory": "Factory for creating TAP::Parser output objects",
   "File::Spec::Win32": "methods for Win32 file specs",
   "Memoize::ExpireTest": "test for Memoize expiration semantics",
   "ExtUtils::Install": "install files from here to there",
-  "IPC::Open3": "open a process for reading, writing, and error handling",
+  "IPC::Open3": "open a process for reading, writing, and error handling using open3()",
   "CPANPLUS::Internals::Report": "CPANPLUS::Internals::Report",
   "ExtUtils::MM_Darwin": "special behaviors for OS X",
-  "Switch": "A switch statement for Perl",
   "Net::Ping": "check a remote host for reachability",
   "Pod::Perldoc::ToMan": "let Perldoc render Pod as man pages",
   "Compress::Raw::Bzip2": "Low-Level Interface to bzip2 compression library",
@@ -470,11 +471,11 @@ perldocSearch.indexData.modules = new Hash ({
   "App::Prove": "Implements the prove command.",
   "Thread::Semaphore": "Thread-safe semaphores",
   "Compress::Zlib": "Interface to zlib compression library",
-  "Tie::SubstrHash": "Fixed-table-size, fixed-key-length hashing",
   "NEXT": "Provide a pseudo-class NEXT (et al) that allows method redispatch",
+  "Tie::SubstrHash": "Fixed-table-size, fixed-key-length hashing",
   "CGI::Apache": "Backward compatibility module for CGI.pm",
-  "Tie::StdHandle": "base class definitions for tied handles",
   "NDBM_File": "Tied access to ndbm files",
+  "Tie::StdHandle": "base class definitions for tied handles",
   "TAP::Parser::Aggregator": "Aggregate TAP::Parser results",
   "Net::SMTP": "Simple Mail Transfer Protocol Client",
   "Pod::Simple::SimpleTree": "parse Pod into a simple parse tree ",
@@ -485,7 +486,6 @@ perldocSearch.indexData.modules = new Hash ({
   "Log::Message": "A generic message storing mechanism;",
   "Devel::Peek": "A data debugging tool for the XS programmer",
   "CPANPLUS::Dist::Base": "Base class for custom distribution classes",
-  "Carp::Heavy": "heavy machinery, no user serviceable parts inside",
   "CGI::Pretty": "module to produce nicely formatted HTML code",
   "File::Spec::Unix": "File::Spec for Unix, base for other File::Spec modules",
   "CPANPLUS::Dist::Build::Constants": "Constants for CPANPLUS::Dist::Build",
@@ -493,7 +493,7 @@ perldocSearch.indexData.modules = new Hash ({
   "TAP::Parser::YAMLish::Reader": "Read YAMLish data from iterator",
   "ExtUtils::MM": "OS adjusted ExtUtils::MakeMaker subclass",
   "Digest::SHA": "Perl extension for SHA-1/224/256/384/512",
-  "Locale::Currency": "ISO three letter codes for currency identification (ISO 4217)",
+  "Locale::Currency": "standard codes for currency identification",
   "DirHandle": "supply object methods for directory handles",
   "Encode::MIME::Name": "internally used by Encode",
   "ExtUtils::MakeMaker::Config": "Wrapper around Config.pm",
@@ -514,5 +514,5 @@ perldocSearch.indexData.modules = new Hash ({
   "Module::Build::Platform::Windows": "Builder class for Windows platforms",
   "O": "Generic interface to Perl Compiler backends",
   "AnyDBM_File": "provide framework for multiple DBMs",
-  "TAP::Parser::Iterator::Array": "Internal TAP::Parser array Iterator"
+  "TAP::Parser::Iterator::Array": "Iterator for array-based TAP sources"
 });
